@@ -239,6 +239,26 @@ def:
 	}
 }
 
+static int
+cmd_addbutton (struct session *sess, char *tbuf, char *word[],
+					char *word_eol[])
+{
+	if (*word[2] && *word_eol[3])
+	{
+		if (sess->type == SESS_DIALOG)
+		{
+			list_addentry (&dlgbutton_list, word_eol[3], word[2]);
+			fe_dlgbuttons_update (sess);
+		} else
+		{
+			list_addentry (&button_list, word_eol[3], word[2]);
+			fe_buttons_update (sess);
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static int
 cmd_allchannels (session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -748,7 +768,9 @@ static int
 cmd_cycle (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	char *key = sess->channelkey;
-	char *chan = sess->channel;
+	char *chan = word[2];
+	if (!*chan)
+		chan = sess->channel;
 	if (*chan && sess->type == SESS_CHANNEL)
 	{
 		sess->server->p_cycle (sess->server, chan, key);
@@ -924,6 +946,26 @@ cmd_debug (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	return TRUE;
 }
 
+static int
+cmd_delbutton (struct session *sess, char *tbuf, char *word[],
+					char *word_eol[])
+{
+	if (*word[2])
+	{
+		if (sess->type == SESS_DIALOG)
+		{
+			if (list_delentry (&dlgbutton_list, word[2]))
+				fe_dlgbuttons_update (sess);
+		} else
+		{
+			if (list_delentry (&button_list, word[2]))
+				fe_buttons_update (sess);
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static int
 cmd_dehop (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
@@ -1142,10 +1184,10 @@ menu_del (char *path, char *label)
 static char
 menu_is_mainmenu_root (char *path, gint16 *offset)
 {
-	static const char *menus[] = {"\x4$TAB","\x5$TRAY","\x4$URL","\x5$NICK"};
+	static const char *menus[] = {"\x4$TAB","\x5$TRAY","\x4$URL","\x5$NICK","\x5$CHAN"};
 	int i;
 
-	for (i = 0; i < 4; i++)
+	for (i = 0; i < 5; i++)
 	{
 		if (!strncmp (path, menus[i] + 1, menus[i][0]))
 		{
@@ -1217,7 +1259,7 @@ cmd_menu (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	int idx = 2;
 	int len;
 	int pos = 0xffff;
-	int state;
+	int state = 0;
 	int toggle = FALSE;
 	int enable = TRUE;
 	int markup = FALSE;
@@ -2029,21 +2071,21 @@ cmd_ghost (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_gui (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	switch (str_ihash (word[2]))
+	switch (str_ihash ((unsigned char *) word[2]))
 	{
-	case 0x058b836e: fe_ctrl_gui (sess, FE_GUI_APPLY, 0); break;
-	case 0xac1eee45: fe_ctrl_gui (sess, FE_GUI_ATTACH, 2); break;
-	case 0x05a72f63: fe_ctrl_gui (sess, FE_GUI_COLOR, atoi (word[3])); break;
-	case 0xb06a1793: fe_ctrl_gui (sess, FE_GUI_ATTACH, 1); break;
-	case 0x05cfeff0: fe_ctrl_gui (sess, FE_GUI_FLASH, 0); break;
-	case 0x05d154d8: fe_ctrl_gui (sess, FE_GUI_FOCUS, 0); break;
-	case 0x0030dd42: fe_ctrl_gui (sess, FE_GUI_HIDE, 0); break;
-	case 0x61addbe3: fe_ctrl_gui (sess, FE_GUI_ICONIFY, 0); break;
+	case 0x058b836e: fe_ctrl_gui (sess, 8, 0); break; /* APPLY */
+	case 0xac1eee45: fe_ctrl_gui (sess, 7, 2); break; /* ATTACH */
+	case 0x05a72f63: fe_ctrl_gui (sess, 4, atoi (word[3])); break; /* COLOR */
+	case 0xb06a1793: fe_ctrl_gui (sess, 7, 1); break; /* DETACH */
+	case 0x05cfeff0: fe_ctrl_gui (sess, 3, 0); break; /* FLASH */
+	case 0x05d154d8: fe_ctrl_gui (sess, 2, 0); break; /* FOCUS */
+	case 0x0030dd42: fe_ctrl_gui (sess, 0, 0); break; /* HIDE */
+	case 0x61addbe3: fe_ctrl_gui (sess, 5, 0); break; /* ICONIFY */
 	case 0xc0851aaa: fe_message (word[3], FE_MSG_INFO|FE_MSG_MARKUP); break; /* MSGBOX */
-	case 0x0035dafd: fe_ctrl_gui (sess, FE_GUI_SHOW, 0); break;
-	case 0x0033155f:
+	case 0x0035dafd: fe_ctrl_gui (sess, 1, 0); break; /* SHOW */
+	case 0x0033155f: /* MENU */
 		if (!strcasecmp (word[3], "TOGGLE"))
-			fe_ctrl_gui (sess, FE_GUI_MENU, 0);
+			fe_ctrl_gui (sess, 6, 0);
 		else
 			return FALSE;
 		break;
@@ -2121,6 +2163,7 @@ cmd_help (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	int i = 0, longfmt = 0;
 	char *helpcmd = "";
+	GSList *list;
 
 	if (tbuf)
 		helpcmd = word[2];
@@ -2159,10 +2202,12 @@ cmd_help (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		buf[2] = 0;
 		hl.t = 0;
 		hl.i = 0;
-
-		for (GList *i = command_list; i; i = g_list_next (i)) {
-			pop = i->data;
+		list = command_list;
+		while (list)
+		{
+			pop = list->data;
 			show_help_line (sess, &hl, pop->name, pop->cmd);
+			list = list->next;
 		}
 		strcat (buf, "\n");
 		PrintText (sess, buf);
@@ -2928,13 +2973,8 @@ cmd_settab (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_settext (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	if (*word_eol[2])
-	{
-		fe_set_inputbox_contents (sess, word_eol[2]);
-		return TRUE;
-	}
-
-	return FALSE;
+	fe_set_inputbox_contents (sess, word_eol[2]);
+	return TRUE;
 }
 
 static int
@@ -3465,6 +3505,8 @@ cmd_voice (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 
 /* *MUST* be kept perfectly sorted for the bsearch to work */
 const struct commands xc_cmds[] = {
+	{"ADDBUTTON", cmd_addbutton, 0, 0, 1,
+	 N_("ADDBUTTON <name> <action>, adds a button under the user-list")},
 	{"ALLCHAN", cmd_allchannels, 0, 0, 1,
 	 N_("ALLCHAN <cmd>, sends a command to all channels you're in")},
 	{"ALLCHANL", cmd_allchannelslocal, 0, 0, 1,
@@ -3491,7 +3533,7 @@ const struct commands xc_cmds[] = {
 	{"CTCP", cmd_ctcp, 1, 0, 1,
 	 N_("CTCP <nick> <message>, send the CTCP message to nick, common messages are VERSION and USERINFO")},
 	{"CYCLE", cmd_cycle, 1, 1, 1,
-	 N_("CYCLE, parts current channel and immediately rejoins")},
+	 N_("CYCLE [<channel>], parts the current or given channel and immediately rejoins")},
 	{"DCC", cmd_dcc, 0, 0, 1,
 	 N_("\n"
 	 "DCC GET <nick>                      - accept an offered file\n"
@@ -3506,6 +3548,8 @@ const struct commands xc_cmds[] = {
 
 	{"DEHOP", cmd_dehop, 1, 1, 1,
 	 N_("DEHOP <nick>, removes chanhalf-op status from the nick on the current channel (needs chanop)")},
+	{"DELBUTTON", cmd_delbutton, 0, 0, 1,
+	 N_("DELBUTTON <name>, deletes a button from under the user-list")},
 	{"DEOP", cmd_deop, 1, 1, 1,
 	 N_("DEOP <nick>, removes chanop status from the nick on the current channel (needs chanop)")},
 	{"DEVOICE", cmd_devoice, 1, 1, 1,
@@ -3626,7 +3670,7 @@ const struct commands xc_cmds[] = {
 	{"SERVER", cmd_server, 0, 0, 1,
 	 N_("SERVER <host> [<port>] [<password>], connects to a server, the default port is 6667")},
 #endif
-	{"SET", cmd_set, 0, 0, 1, N_("SET [-e] [-quiet] <variable> [<value>]")},
+	{"SET", cmd_set, 0, 0, 1, N_("SET [-e] [-or] [-quiet] <variable> [<value>]")},
 	{"SETCURSOR", cmd_setcursor, 0, 0, 1, N_("SETCURSOR [-|+]<position>")},
 	{"SETTAB", cmd_settab, 0, 0, 1, 0},
 	{"SETTEXT", cmd_settext, 0, 0, 1, 0},
@@ -4023,7 +4067,7 @@ static void
 user_command (session * sess, char *tbuf, char *cmd, char *word[],
 				  char *word_eol[])
 {
-	if (!auto_insert (tbuf, 2048, cmd, word, word_eol, "", sess->channel, "",
+	if (!auto_insert (tbuf, 2048, (unsigned char *) cmd, word, word_eol, "", sess->channel, "",
 							server_get_network (sess->server, TRUE), "",
 							sess->server->nick, ""))
 	{
@@ -4169,6 +4213,7 @@ handle_command (session *sess, char *cmd, int check_spch)
 {
 	struct popup *pop;
 	int user_cmd = FALSE;
+	GSList *list;
 	char *word[PDIWORDS];
 	char *word_eol[PDIWORDS];
 	static int command_level = 0;
@@ -4217,13 +4262,16 @@ handle_command (session *sess, char *cmd, int check_spch)
 		goto xit;
 
 	/* first see if it's a userCommand */
-	for (GList *i = command_list; i; i = g_list_next (i)) {
-		pop = (struct popup *) i->data;
+	list = command_list;
+	while (list)
+	{
+		pop = (struct popup *) list->data;
 		if (!strcasecmp (pop->name, word[1]))
 		{
 			user_command (sess, tbuf, pop->cmd, word, word_eol);
 			user_cmd = TRUE;
 		}
+		list = list->next;
 	}
 
 	if (user_cmd)
