@@ -1,7 +1,7 @@
 /*
  * gui.h - main gui information structure
  *
- * Copyright (C) 2004-2006 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,9 +23,8 @@
 #define XCHAT_GNOME_GUI_H
 
 #include <glade/glade.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <libgnome/gnome-program.h>
 #include "userlist.h"
 #include "navigation-tree.h"
 #include "dcc-window.h"
@@ -47,6 +46,7 @@ typedef struct
 	GtkWidget *userlist;
 	GtkWidget *userlist_toggle;
 	session *current_session;
+	gboolean initialized;
 	gboolean quit;
 
 	GtkWidget *conversation_panel;
@@ -55,6 +55,8 @@ typedef struct
 	GtkWidget *status_bar;
 	GtkWidget *text_entry;
 	GtkWidget *topic_label;
+	GtkWidget *topic_hbox;
+	GtkWidget *nick_button;
 
 	NavModel *tree_model;
 	NavTree *server_tree;
