@@ -19,10 +19,7 @@
  *
  */
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtktreeviewcolumn.h>
+#include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
 #include "irc-network.h"
