@@ -1,7 +1,7 @@
 /*
  * preferences.h - interface to storing preferences
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,15 +19,13 @@
  *
  */
 
-#include <gnome.h>
-#include "../common/xchat.h"
-#include "../common/servlist.h"
-
 #ifndef XCHAT_GNOME_PREFERENCES_H
 #define XCHAT_GNOME_PREFERENCES_H
 
-gboolean preferences_exist ();
-void load_preferences ();
-void set_version ();
+gboolean preferences_exist (void);
+void load_preferences (void);
+void set_version (void);
+void set_nickname (const gchar *nick);
+gchar *get_save_directory(void);
 
 #endif
